/**
 * Settings scripts
 *
 * @author  WooThemes
 * @package WC_OD
 * @since   1.0.0
 */

/**
 * Settings function.
 *
 * @param {jQuery} $       The jQuery instance.
 * @param {Object} options The WC_OD settings options.
 */
;(function( $, options ) {

	'use strict';

	var WC_OD_Settings = {
		init: function() {
			var $timepickers = $( '.timepicker' ),
			    $eventCalendar = $( '.wc-od-calendar-field' );

			// Init timepickers
			if ( $timepickers.length ) {
				$( '.timepicker' ).timepicker( { timeFormat: 'H:i', maxTime: '23:59' } );
			}

			this.deliveryCheckoutOptionsToggle();
			this.statusToggle();
			this.madeSortable();

			if ( $eventCalendar.length && $.isFunction( $.fn.WC_OD_Calendar ) ) {
				// Init calendar.
				if ( 'delivery' === options.eventsType ) {
					$eventCalendar.WC_OD_Delivery_Calendar( options );
				} else {
					$eventCalendar.WC_OD_Calendar( options );
				}
			}
		},
		deliveryCheckoutOptionsToggle: function() {
			var $field = $( 'input[name="wc_od_checkout_delivery_option"]' ),
				$toggleFields = $(
					'.wc_od_time_frames,' +
					'.wc_od_delivery_days,' +
					'#wc_od_max_delivery_days,' +
					'[name="wc_od_delivery_date_field"],' +
					'#wc_od_subscriptions_limit_to_billing_interval'
				).closest( 'tr' );

			if ( $field.length ) {
				if ( 'text' === $field.filter( ':checked' ).val() ) {
					$toggleFields.hide();
				}

				$field.on( 'change', function() {
					$toggleFields.toggle();
				});
			}
		},
		statusToggle: function() {
			$( '.wc-od-input-toggle input[type="checkbox"]' ).change(function() {
				var $toggle = $( this ).siblings( 'span' );

				if ( $( this ).prop( 'checked' ) ) {
					$toggle.attr( 'class', $toggle.attr( 'class' ).replace( 'disabled', 'enabled' ) );
				} else {
					$toggle.attr( 'class', $toggle.attr( 'class' ).replace( 'enabled', 'disabled' ) );
				}
			});
		},
		madeSortable: function() {
			$( 'table.wc-od-field-table.sortable tbody' ).sortable({
				items: 'tr',
				cursor: 'move',
				axis: 'y',
				handle: 'td.sort',
				scrollSensitivity: 40,
				helper: function( event, ui ) {
					ui.children().each( function() {
						$( this ).width( $( this ).width() );
					});
					ui.css( 'left', '0' );
					return ui;
				},
				start: function( event, ui ) {
					ui.item.css( 'background-color', '#f6f6f6' );
				},
				stop: function( event, ui ) {
					ui.item.removeAttr( 'style' );
				}
			});
		}
	};

	$(function() {
		WC_OD_Settings.init();
	});
})( jQuery, wc_od_settings_l10n );